#!/usr/bin/python
"""fiwalk_all.py:

Walks all of the images in indir; for each one, produce a .xml file in the output directory.
"""

global indir,outdir
indir  = "/corp/images/nus/"
outdir = "/corp/fiwalk/nus/"

import sys, os, os.path
sys.path.append(os.getenv("DOMEX_HOME") + "/src/lib/") # add the library
sys.path.append("../lib/")      # add the library


max_processes = 2
running_processes = set()

def needs_processing(xmlfile):
    """Examines an xmlfile to see if it needs processing. Returns the reason why"""
    from fiwalk import fiwalk_installed_version,fiwalk_xml_version
    if not os.path.exists(xmlfile):
        return "Does not exist"
    if fiwalk_installed_version() != fiwalk_xml_version(xmlfile):
        return "Wrong XML version"
    return False

def process(infile):
    """ Check if the file f has been processed yet. If not, process it"""
    import time,sys
    from subprocess import Popen,PIPE
    global options,running_processes,indir,outdir
    xmlfile = infile.replace(indir,outdir).replace(".aff",".xml")
    why = needs_processing(xmlfile)
    if not why:
        if options.debug: print "will not process %s: %s" % (infile,why)
        return
    cmd = ["src/fiwalk","-X",xmlfile,"-1",infile]
    print time.asctime(time.localtime(time.time()))+": " + " ".join(cmd)
    if options.debug: return

    # Looks like we are running
    # See if we are at max processes ...
    while len(running_processes)>max_processes:
        for p in running_processes.copy():
            if p.poll()!=None:
                running_processes.remove(p)
        time.sleep(1)
    p = Popen(cmd,stdout=sys.stderr,stderr=sys.stderr)
    p.fname = infile
    running_processes.add(p)
    print "Total processes: %d  processing %s" % (len(running_processes),infile)

if(__name__=='__main__'):
    import glob,re,os.path,sys
    from optparse import OptionParser
    global options
    parser = OptionParser()
    parser.add_option("-d","--debug",action="store_true", help="Don't actually run")

    parser.usage = "%prog [options] [files]\nIf [files] is not specified, will process from INDIR"
    (options,args) = parser.parse_args()

    if len(args):
        for a in args:
            process(a)
        sys.exit(0)

    # Otherwise, process the default directory
    for (root, dirs, files) in os.walk(indir):
        for f in files:
            fn = root +  f
            if fn.endswith(".aff"):
                process(fn)


                    
